<?php
/**
 *  plugins/forced_prefs/setup.php -- Displays the main frameset
 *
 * SquirrelMail Forced Prefs Plugin
 * Copyright (C) 2004-2006 Tomas Kuliavas <tokul@users.sourceforge.net>
 * This program is licensed under GPL. See COPYING for details
 *
 * Redirects to the login page.
 *
 * @package sm-plugins
 * @subpackage forced_prefs
 * @version $Id: index.php,v 1.4 2006/04/18 09:25:06 tokul Exp $
 */
header("Location: ../../index.php\n\n");
exit();
?>
